--[[
	Copyright (C) Udorn (Blackhand)
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.	
--]]

--[[
	Cell object for rendering texts. Input for the cell is:
	text
--]]
vendor.TextCell = {}
vendor.TextCell.prototype = {}
vendor.TextCell.metatable = {__index = vendor.TextCell.prototype}
setmetatable(vendor.TextCell.prototype, {__index = vendor.ItemTableCell.prototype})

--[[
	Shows information if mouse is over the selected item
--]]
local function _OnEnterItem(but)
	local self = but.obj
	if (self.item) then
		GameTooltip:SetOwner(but, "ANCHOR_RIGHT")
		GameTooltip.itemCount = self.item.count
		GameTooltip:SetHyperlink(self.item.itemLink)
	end
end

--[[
	Initializes the cell.
--]]
local function _Init(self)
	local f = self.parent:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	f:SetWidth(self.width)
	f:SetHeight(self.height)
	if (self.align) then
		f:SetJustifyH(self.align)
	end
	self.frame = f
end

--[[ 
	Creates a new instance.
--]]
function vendor.TextCell:new(parent, width, height, align)
	local instance = setmetatable({}, self.metatable)
	instance.parent = parent
	instance.width = width
	instance.height = height
	instance.align = align
	_Init(instance)
	return instance
end

--[[
	Updates the cell with the required input parameters of the cell.
--]]
function vendor.TextCell.prototype:Update(text)
	self.frame:SetText(text)
end
